@@ -17,11 +17,11 @@ def exec_polqa_test():
         curdata = global_result.get_data()
         curdata['module'] = 'clientB'
         curdata['method'] = 'requestB'
-
-        curruslt = socket.sender(curdata)
-        print(curruslt)
-        socket.close()
-        print(curruslt['job'])
+        try:
+            curruslt = socket.sender(curdata)
+        except:
+            socket.close()
+            continue
         if curruslt['job'] is None or str(curruslt['job']) == 'null':
             continue
 
@@ -35,15 +35,15 @@ def exec_polqa_test():
         sftp_disconnect(client)
         srf ,tsf, fpath,sr = curruslt['token'] +'/'+ curruslt['srcFile'],curruslt['token'] +'/'+ curruslt['testFile'],curruslt['token'],curruslt['samplerate']
         if not os.path.exists(srf) or not os.path.exists(tsf):
-            curruslt['err'] = 'lack of input files!'
+            curruslt['result'] = 'lack of input files!'
             socket = SocketClient(global_result.machost, global_result.PORT)
             curruslt['module'] = 'clientB'
             curruslt['method'] = 'response'
-            douresult = socket.sender(curruslt)
-            socket.close()
             try:
-                shutil.rmtree(fpath)
+                douresult = socket.sender(curruslt)
             except:
+                socket.close()
+                shutil.rmtree(fpath)
                 print(fpath,' is not exist')
             continue
 
@@ -55,12 +55,13 @@ def exec_polqa_test():
         socket = SocketClient(global_result.machost, global_result.PORT)
         curruslt['module'] = 'clientB'
         curruslt['method'] = 'response'
-        socket.sender(curruslt)
-        socket.close()
-        time.sleep(1)
+        print(curruslt)
         try:
-            shutil.rmtree(fpath)
+            socket.sender(curruslt)
         except:
+            socket.close()
+            time.sleep(1)
+            shutil.rmtree(fpath)
             print('file was not deleted!')
 
 
