@@ -8,7 +8,7 @@ from formatConvert.wav_pcm import wav2pcm,pcm2wav
 from G160.G160 import cal_g160
 from P563.P563 import cal_563_mos
 from PESQ.PESQ import cal_pesq
-#from POLQA.polqa_client import  polqa_client_test
+from POLQA.polqa_client import  polqa_client_test
 from SDR.SDR import cal_sdr
 from STI.cal_sti import cal_sti
 from STOI.STOI import cal_stoi
@@ -142,11 +142,9 @@ class computeAudioQuality():
 
         self.__double_end_check()
         curCH,curBwidth,curSR = self.__check_format(self.testFile)
-        from algorithmLib.POLQA.POLQA import startvqt
-        from algorithmLib.POLQA.POLQA import vqtDisConnect
-        result =  startvqt(wav2pcm(self.refFile),wav2pcm(self.testFile),curSR)
+
+        result =  polqa_client_test(wav2pcm(self.refFile),wav2pcm(self.testFile),curSR)
         time.sleep(2)
-        vqtDisConnect()
         return  result
 
 
